from .format import *
import itertools
from .abc import Array as Array
from .array1d import Array1D as Array1D
from collections.abc import Sequence
from typing import Any, TypeVar

T = TypeVar('T')
Boundaries = tuple[tuple[int, int], ...]

class ArrayND(Array):
    index_format: Union[str, None]
    def __init__(self, dim: int, default: Union[T, None] = ..., *, content: Union[Sequence, None] = ..., offset: Union[tuple[int, ...], list[int], int] = ...) -> None: ...
    @property
    def dim(self) -> int: ...
    @property
    def offset(self) -> tuple[int, ...]: ...
    @property
    def shape(self) -> tuple[int, ...]: ...
    @property
    def boundaries(self) -> Boundaries: ...
    def replace_content(self, array: Sequence, offset: Union[tuple[int, ...], list[int], int] = ...) -> None: ...
    def __setitem__(self, index: tuple[int, ...], value: T) -> None: ...
    def __getitem__(self, index: Union[int, tuple[int, ...], slice]) -> Any: ...
    def __iter__(self) -> itertools.chain: ...
    def __len__(self) -> int: ...
    def __format__(self, format: str) -> str: ...



from .format import *
import itertools
from .abc import Array as Array
from collections.abc import Iterable, Iterator
from typing import TypeVar

T = TypeVar('T')
Boundaries = tuple[tuple[int, int], ...]

class Array1D(Array):
    def __init__(self, default: Union[T, None] = ..., *, content: Union[Iterable, None] = ..., offset: int = ...) -> None: ...
    @property
    def dim(self) -> int: ...
    @property
    def offset(self) -> int: ...
    @property
    def boundaries(self) -> tuple[int, int]: ...
    def replace_content(self, content: Iterable, offset: int = ...) -> None: ...
    def __setitem__(self, index: Union[int, slice], value: Union[T, None]) -> None: ...
    def __getitem__(self, index: Union[int, slice]) -> Union[T, Iterator, None]: ...
    def __iter__(self) -> itertools.chain: ...
    def __len__(self) -> int: ...
    def __format__(self, format: str) -> str: ...



from .array1d import Array1D
from .arraynd import ArrayND
from collections.abc import Iterable, Sequence
from typing import Any

def array(content: Union[Sequence, Iterable, None] = ..., *, default: Any = ..., offset: Union[tuple[int, ...], list[int], int] = ..., dim: Union[int, None] = ...) -> Union[Array1D, ArrayND]: ...
def empty(dim: int = ..., default: Any = ...) -> Union[Array1D, ArrayND]: ...



from collections.abc import Iterable
from typing import Any

class Formatter:
    sep: str
    rowend: str
    begin: str
    end: str
    index: bool
    arrange: bool
    index_format: str
    def __init__(self, default: Any = ...) -> None: ...
    @property
    def literal(self) -> bool: ...
    @literal.setter
    def literal(self, value: bool) -> None: ...
    @property
    def output(self) -> str: ...
    def reset(self) -> None: ...
    def update_maxwidth(self, content: Iterable) -> None: ...
    def update_maxwidth_default(self) -> None: ...
    def output_iter(self, content: Iterable) -> None: ...
    def output_begin(self) -> None: ...
    def output_end(self) -> None: ...
    def output_firstrow(self, indent: str, index: list[int] = ...) -> None: ...
    def output_rowsep(self, separator: str, indent: str, index: list[int] = ...) -> None: ...
    def output_string(self, content: str) -> None: ...
    def apply_format_string(self, format_string: str) -> None: ...

class StrFormatter(Formatter):
    begin: str
    end: str
    arrange: bool

class ReprFormatter(Formatter):
    sep: str
    rowend: str
    begin: str
    end: str
    arrange: bool
